@@ -6,7 +6,7 @@
 
    see qh-stat.htm and stat.h
 
-   copyright (c) 1993-2001, The Geometry Center
+   copyright (c) 1993-2003, The Geometry Center
 */
 
 #include "qhull_a.h"
@@ -137,12 +137,14 @@ void qh_allstatD(void) {
   zdef_(zinc, Zparthorizon, " horizon facets better than bestfacet", -1);
   zdef_(zinc, Zpartangle, "angle tests for repartitioned coplanar points", -1);
   zdef_(zinc, Zpartflip, "  repartitioned coplanar points for flipped orientation", -1);
+}
+void qh_allstatE(void) {
   zdef_(zinc, Zpartinside, "inside points", -1);
   zdef_(zinc, Zpartnear, "  inside points kept with a facet", -1);
   zdef_(zinc, Zcoplanarinside, "  inside points that were coplanar with a facet", -1);
+  zdef_(zinc, Zbestlower, "calls to findbestlower", -1);
+  zdef_(zinc, Zbestlowerv, "  with search of vertex neighbors", -1);
   zdef_(wadd, Wmaxout, "difference in max_outside at final check", -1);
-}
-void qh_allstatE(void) {
   zzdef_(zinc, Zpartitionall, "distance tests for initial partition", -1);
   zdef_(zinc, Ztotpartition, "partitions of a point", -1);
   zzdef_(zinc, Zpartition, "distance tests for partitioning", -1);
@@ -458,7 +460,7 @@ void qh_initstatistics (void) {
   qh_allstatI();
   if (qhstat next > sizeof(qhstat id)) {
     fprintf (qhmem.ferr, "qhull error (qh_initstatistics): increase size of qhstat.id[].\n\
-      qhstat.next %d should be <= sizeof(qhstat id) %d\n", qhstat next, sizeof(qhstat id));
+      qhstat.next %d should be <= sizeof(qhstat id) %lu\n", qhstat next, sizeof(qhstat id));
 #if 0 /* for locating error, Znumridges should be duplicated */
     for (i=0; i < ZEND; i++) {
       int j;
